@@ -1,24 +1,24 @@
-use clickhouse::{error::Result, test, Client, Reflection};
+use clickhouse::{error::Result, test, Client, Row};
 use futures::stream;
 use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Clone, PartialEq)]
-#[derive(Serialize, Deserialize, Reflection)]
-struct Row {
+#[derive(Serialize, Deserialize, Row)]
+struct SomeRow {
     no: u32,
 }
 
-async fn make_select(client: &Client) -> Result<Vec<Row>> {
+async fn make_select(client: &Client) -> Result<Vec<SomeRow>> {
     client
         .query("SELECT ?fields FROM `who cares`")
-        .fetch_all::<Row>()
+        .fetch_all::<SomeRow>()
         .await
 }
 
-async fn make_insert(client: &Client, data: &[Row]) -> Result<()> {
+async fn make_insert(client: &Client, data: &[SomeRow]) -> Result<()> {
     let mut insert = client.insert("who cares")?;
     for row in data {
-        insert.write(&row).await?;
+        insert.write(row).await?;
     }
     insert.end().await
 }
@@ -28,7 +28,7 @@ async fn main() {
     let mock = test::Mock::new();
     let client = Client::default().with_url(mock.url());
 
-    let list = vec![Row { no: 1 }, Row { no: 2 }];
+    let list = vec![SomeRow { no: 1 }, SomeRow { no: 2 }];
 
     // How to test SELECTs.
     mock.add(test::handlers::provide(stream::iter(list.clone())));
@@ -44,6 +44,6 @@ async fn main() {
     let recording = mock.add(test::handlers::record());
     make_insert(&client, &list).await.unwrap();
 
-    let rows: Vec<Row> = recording.collect().await;
+    let rows: Vec<SomeRow> = recording.collect().await;
     assert_eq!(rows, list);
 }
